@@ -206,6 +206,7 @@ int WinMain(void) {
 static void add_arg(char *p) {
   cmdarg *ap;
   ap = malloc(sizeof(cmdarg));
+  if (ap == NULL) return;
   ap->argvalue = p;
   ap->nextarg = NIL;
   if (arglast == NIL)
@@ -241,6 +242,7 @@ static void init1(void) {
   basicvars.debug_flags.stack = FALSE;
   basicvars.debug_flags.allstack = FALSE;
   basicvars.debug_flags.vdu = FALSE;
+  basicvars.debug_flags.sound = FALSE;
 #endif
   basicvars.errorislocal = 0;
 
@@ -280,6 +282,9 @@ static void init1(void) {
   matrixflags.tekenabled = 0;         /* Tektronix enabled in text mode (default: no) */
   matrixflags.tekspeed = 0;
   matrixflags.osbyte4val = 0;         /* Default OSBYTE 4 value */
+#ifdef USE_SDL
+  matrixflags.videoscale = 1;         /* Default scale by 1 */
+#endif
 #if (defined(TARGET_UNIX) & !defined(USE_SDL)) | defined(TARGET_MACOSX)
   matrixflags.delcandelete = 1;       /* DEL character can delete? */
 #else
@@ -367,6 +372,7 @@ static void check_configfile() {
   char *conffname, *line, *item, *parameter;
 
   conffname=malloc(1024);
+  if(conffname == NULL) return;
   memset(conffname, 0, 1024);
 #ifdef TARGET_RISCOS
   snprintf(conffname, 1023, "<Brandy$Dir>.brandyrc");
@@ -389,6 +395,11 @@ static void check_configfile() {
     return;
   }
   line=malloc(1024);
+  if(line == NULL) {
+    fclose(conffile);
+    free(conffname);
+    return;
+  }
   while (!feof(conffile)) {
     memset(line,0,1024);          /* Clear the buffer before new entries are read */
     parameter=NULL;
@@ -421,6 +432,12 @@ static void check_configfile() {
       matrixflags.neverfullscreen=TRUE;
     } else if(!strncmp(item, "swsurface", 10)) {
       basicvars.runflags.swsurface=TRUE;
+    } else if(!strncmp(item, "zoom", 5)) {
+      if(parameter) {
+        char *sp;
+        matrixflags.videoscale = CAST(strtol(parameter, &sp, 10), size_t);
+        if ((matrixflags.videoscale < 1) || (matrixflags.videoscale > 4)) matrixflags.videoscale = 1;
+      }
 #endif
     } else if(!strncmp(item,"lowercase",10)) {
       matrixflags.lowercasekeywords = TRUE;
@@ -431,29 +448,35 @@ static void check_configfile() {
     } else if(!strncmp(item, "nostar", 7)) {
       basicvars.runflags.ignore_starcmd = TRUE;
     } else if(!strncmp(item, "size", 5)) {
-      char *sp;
-      worksize = CAST(strtol(parameter, &sp, 10), size_t);  /* Fetch workspace size (n.b. no error checking) */
-      if (tolower(*sp)=='k') {          /* Size is in kilobytes */
-        worksize = worksize*1024;
-      } else if (tolower(*sp)=='m') {   /* Size is in megabytes */
-        worksize = worksize*1024*1024;
-      } else if (tolower(*sp)=='g') {   /* Size is in gigabytes */
-        worksize = worksize*1024*1024*1024;
+      if(parameter) {
+        char *sp;
+        worksize = CAST(strtol(parameter, &sp, 10), size_t);  /* Fetch workspace size (n.b. no error checking) */
+        if (tolower(*sp)=='k') {          /* Size is in kilobytes */
+          worksize = worksize*1024;
+        } else if (tolower(*sp)=='m') {   /* Size is in megabytes */
+          worksize = worksize*1024*1024;
+        } else if (tolower(*sp)=='g') {   /* Size is in gigabytes */
+          worksize = worksize*1024*1024*1024;
+        }
       }
 #ifndef BRANDY_MODE7ONLY
     } else if(!strncmp(item, "startupmode", 12)) {
-      char *sp;
-      matrixflags.startupmode = CAST(strtol(parameter, &sp, 10), size_t);  /* startup mode */
+      if(parameter) {
+        char *sp;
+        matrixflags.startupmode = CAST(strtol(parameter, &sp, 10), size_t);  /* startup mode */
+      }
 #endif
     } else if(!strncmp(item, "path", 5)) {
-      if (basicvars.loadpath!=NIL) free(basicvars.loadpath);  /* Discard existing list */
-      basicvars.loadpath = malloc(strlen(parameter)+1);         /* +1 for the NUL */
-      if (basicvars.loadpath==NIL) {    /* No memory available */
-        cmderror(CMD_NOMEMORY);
-        exit(EXIT_FAILURE);
+      if(parameter) {
+        if (basicvars.loadpath!=NIL) free(basicvars.loadpath);  /* Discard existing list */
+        basicvars.loadpath = malloc(strlen(parameter)+1);         /* +1 for the NUL */
+        if (basicvars.loadpath==NIL) {    /* No memory available */
+          cmderror(CMD_NOMEMORY);
+          exit(EXIT_FAILURE);
+        }
+        /* This is safe, the required space is allocated a few lines above. */
+        STRLCPY(basicvars.loadpath, parameter, FNAMESIZE);
       }
-      /* This is safe, the required space is allocated a few lines above. */
-      STRLCPY(basicvars.loadpath, parameter, FNAMESIZE);
     } else if(!strncmp(item, "lib", 4)) {
       struct loadlib *p = malloc(sizeof(struct loadlib));
       if (p==NIL) {
@@ -526,6 +549,16 @@ static void check_cmdline(int argc, char *argv[]) {
       else if (optchar=='s' && tolower(*(p+2))=='w') {    /* -swsurface */
         basicvars.runflags.swsurface=TRUE;
       }
+      else if (optchar=='z') {              /* -z */
+        n++;
+        if (n==argc)
+          matrixflags.videoscale = 1;
+        else {
+          char *sp;
+          matrixflags.videoscale = CAST(strtol(argv[n], &sp, 10), size_t);
+          if ((matrixflags.videoscale < 1) || (matrixflags.videoscale > 4)) matrixflags.videoscale = 1;
+        }
+      }
 #endif
 #ifndef BRANDYAPP
 #ifndef BRANDY_NOVERCHECK
@@ -632,6 +665,10 @@ static void check_cmdline(int argc, char *argv[]) {
 #endif /* BRANDYAPP */
     n++;
   }
+#ifdef USE_SDL
+  // Never allow full screen if zoom is in use.
+  if (matrixflags.videoscale != 1) matrixflags.neverfullscreen=TRUE;
+#endif
 
 #ifndef BRANDYAPP
 /* Update program's name in Basic's command line list */
@@ -704,16 +741,13 @@ void init_clock() {
 
 #ifndef TARGET_RISCOS
 static void *timer_thread(void *data) {
-  //struct timeval tv;
   struct timespec tv;
   while(1) {
     clock_gettime(basicvars.clocktype, &tv);
 
     /* tv.tv_sec  = Seconds */
-    // /* tv.tv_usec = and microseconds */
     /* tv.tv_nsec = Nanoseconds */
 
-    //basicvars.centiseconds = (((uint64)tv.tv_sec * 100) + ((uint64)tv.tv_usec / 10000));
     basicvars.centiseconds = (((uint64)tv.tv_sec * 100) + ((uint64)tv.tv_nsec / 10000000));
     usleep(5000);
   }
