@@ -911,7 +911,6 @@ static void fn_eval(void) {
   basicvars.stringwork[descriptor.stringlen] = asc_NUL; /* Now have a null-terminated version of string */
   if (stringtype == STACK_STRTEMP) free_string(descriptor);
   tokenize(basicvars.stringwork, evalexpr, NOLINE, FALSE);      /* 'tokenise' leaves its results in 'thisline' */
-//  tokenize(basicvars.stringwork, evalexpr, NOLINE);   /* 'tokenise' leaves its results in 'thisline' */
   save_current();               /* Save pointer to current position in expression */
   basicvars.current = FIND_EXEC(evalexpr);
   expression();
@@ -1285,6 +1284,10 @@ void fn_mod(void) {
   else {
     vp = get_arrayname();
   }
+  if (vp == NULL) {
+    error(ERR_BROKEN, __LINE__, "functions");
+    return;
+  }
   elements = vp->varentry.vararray->arrsize;
   switch (vp->varflags) {
   case VAR_INTARRAY: {  /* Calculate the modulus of an integer array */
@@ -1628,12 +1631,18 @@ static void fn_str(void) {
   (*factor_table[*basicvars.current])();
   resultype=GET_TOPITEM;
   if (IS_NUMERIC(resultype)) {
-    if (ishex)
-      if (matrixflags.hex64)
+    if (ishex) {
+      if (matrixflags.hex64) {
         length = snprintf(basicvars.stringwork, MAXSTRING, "%llX", pop_anynum64());
-      else
-        length = snprintf(basicvars.stringwork, MAXSTRING, "%X", pop_anynum32());
-    else {
+      } else {
+        int64 result = pop_anynum64();
+        if (basicvars.runflags.flag_cosmetic) {
+          if ((result < MININTVAL) || (result > MAXINTVAL))
+            error(ERR_HEXOVERFLOW);
+        }
+        length = snprintf(basicvars.stringwork, MAXSTRING, "%X", (int32)result);
+      }
+    } else {
       int32 format, numdigits;
       char *fmt, *bufptr;
       format = basicvars.staticvars[ATPERCENT].varentry.varinteger;
@@ -1770,6 +1779,10 @@ static void fn_sum(void) {
   else {
     vp = get_arrayname();
   }
+  if (vp == NULL) {
+    error(ERR_BROKEN, __LINE__, "functions");
+    return;
+  }
   elements = vp->varentry.vararray->arrsize;
   if (sumlen) {         /* Got 'SUM LEN' */
     int32 length;
