@@ -52,32 +52,6 @@ int64 llabs(int64 i) {
 }
 #endif
 
-#if 0 /* Converted to macros in miscprocs.h */
-/*
-** 'isidstart' returns TRUE if the character passed to it can appear at
-** the start of an identifier
-*/
-boolean isidstart(char ch) {
-  return isalpha(ch) || ch=='_' || ch=='`';
-}
-
-/*
-** 'isidchar' returns TRUE if the character passed to it can appear in the
-** middle of an identifier
-*/
-boolean isidchar(char ch) {
-  return isalnum(ch) || ch=='_' || ch=='`';
-}
-
-/*
-** 'isident' is the same as 'isidchar' but is called when the character
-** is an unsigned char.
-*/
-boolean isident(byte ch) {
-  return isalnum(ch) || ch=='_' || ch=='`';
-}
-#endif /* 0 - macro conversion */
-
 /*
 ** 'get_integer' returns the four byte integer found at offset
 ** 'offset' in the Basic workspace. This is used to return the
@@ -334,9 +308,7 @@ byte *find_line(int32 lineno) {
 void show_byte(size_t low, size_t high) {
   int32 n, ll, count;
   byte ch;
-  //if (low<0 || low>=basicvars.worksize || high<0 || low>high) return;
   if (low>high) return;
-  //if (high>basicvars.worksize) high = basicvars.worksize-1;
   count = high-low;
   for (n=0; n<count; n+=16) {
     int32 x = 0;
@@ -380,9 +352,7 @@ void show_word(size_t low, size_t high) {
   byte ch;
   low = ALIGN(low);
   high = ALIGN(high);
-  //if (low<0 || low>=basicvars.worksize || high<0 || low>high) return;
   if (low>high) return;
-  //if (high>basicvars.worksize) high = basicvars.worksize-1;
   count = high-low;
   for (n=0; n<count; n+=16) {
     emulate_printf("%06X  +%04X  %08X  %08X  %08X  %08X  ",
@@ -435,7 +405,6 @@ boolean read_line(char line[], int32 linelen) {
   readstate result;
   line[0] = asc_NUL;
   result = kbd_readline(line, linelen, 0);
-  //result = READ_OK;     /* temp'y bodge */
   if (result==-READ_ESC || basicvars.escape) {
     error(ERR_ESCAPE);
     return FALSE;
@@ -458,7 +427,6 @@ boolean read_line(char line[], int32 linelen) {
 boolean amend_line(char line[], int32 linelen) {
   readstate result;
   result = kbd_readline(line, linelen,0);
-  //result = READ_OK;     /* temp'y bodge */
   if (result==-READ_ESC || basicvars.escape) {
     error(ERR_ESCAPE);
     return FALSE;
@@ -522,7 +490,6 @@ size_t TONATIVEADDR(float64 fltmp) {
 ** to allow negative 32-bit ints to be entered as hex.
 */
 int32 INT64TO32(int64 itmp) {
-//  if ((itmp > 2147483647ll) || (itmp < -2147483648ll)) error(ERR_RANGE);
   if ((itmp > 4294967295ll) || (itmp < -2147483648ll)) error(ERR_RANGE); /* Allow &80000000-FFFFFFFF */
   return (int32)itmp;
 }
@@ -617,6 +584,7 @@ int32 get_listo(void) {
         | basicvars.debug_flags.allstack<<14
         | basicvars.debug_flags.functions<<15
         | basicvars.debug_flags.vdu<<16
+        | basicvars.debug_flags.sound<<17
 #endif
         );
 }
@@ -641,6 +609,7 @@ void set_listoption(int32 listopts) {
   basicvars.debug_flags.allstack = (listopts & DEBUG_ALLSTACK) != 0;
   basicvars.debug_flags.functions = (listopts & DEBUG_FUNCTIONS) != 0;
   basicvars.debug_flags.vdu = (listopts & DEBUG_VDU) != 0;
+  basicvars.debug_flags.sound = (listopts & DEBUG_SOUND) != 0;
 #endif
   DEBUGFUNCMSGOUT;
 }
