@@ -290,7 +290,16 @@ int brandynet_connect(char *dest, char type, int reporterrors) {
   hints.ai_protocol = IPPROTO_TCP;
 
   host=strdup(dest);
+  if (host == NULL) {
+    error(ERR_NET_NOTFOUND);
+    return(-1);
+  }
   port=strchr(host,':');
+  if (port == NULL) {
+    free(host);
+    error(ERR_NET_NOTFOUND);
+    return(-1);
+  }
   port[0]='\0';
   port++;
 
@@ -425,11 +434,12 @@ int net_bputstr(int handle, char *string, int32 length) {
  * version. This is a quick and dirty implementation talking raw HTML!
  */
 int checkfornewer() {
-  int hndl, ptr, val, vermaj, vermin, verpatch;
+  int hndl, ptr, val, vermaj, vermin, verpatch, lc;
   char *inbuf, *verstr, *ptra, *request;
 
   DEBUGFUNCMSGIN;
   inbuf=malloc(8192);
+  if (inbuf == NULL) return(0);
   memset(inbuf, 0, 4096);
   hndl=brandynet_connect("brandy.matrixnetwork.co.uk:80", 0, 0);
   if (hndl < 0) {
@@ -447,6 +457,7 @@ int checkfornewer() {
   free(request);
   ptr = 0;
   val=-1;
+  lc=0;
   while (val != -2) {
     val=net_bget(hndl);
     if (val >= 0) {
@@ -454,12 +465,22 @@ int checkfornewer() {
       ptr++;
     } else {
       usleep(10000);
+      lc++;                                             /* Increment loop counter */
+      /* If we have hung for a second or have data in the buffer already, stop waiting */
+      if ((lc >= 100) || ((val == -1) && (ptr > 0))) val=-2;
     }
   }
   brandynet_close(hndl);
-  if (strlen(inbuf) == 0) return(2);
+  if (strlen(inbuf) == 0) {
+    free(inbuf);
+    return(2);
+  }
   verstr=strstr(inbuf, "\r\n\r\n");
   verstr+=4;
+  if ((*verstr < 48) || (*verstr > 57)) {
+    free(inbuf);
+    return(2);
+  }
   ptra=strchr(verstr, '\n'); *ptra='\0';
   ptra=strchr(verstr, '.'); *ptra='\0';
   vermaj=atoi(verstr);
