@@ -194,19 +194,6 @@ sigjmp_buf *make_restart(void) {
   return &basicvars.stacktop.restartsp->restart;
 }
 
-/*
-** 'get_safestack' returns the value that the stack pointer is set
-** to after an error to restore the stack to a known condition
-*/
-#if 0 /* Code disabled; only used in one place and it's a global struct variable */
-byte *get_safestack(void) {
-#ifdef DEBUG
-  if (basicvars.debug_flags.stack) fprintf(stderr, "Get safestack = %p\n", basicvars.safestack.bytesp);
-#endif
-  return basicvars.safestack.bytesp;
-}
-#endif
-
 /* Pushes an int of variable size, using the most appropriate type */
 void push_varyint(int64 value) {
   if (value == (uint8)value) {
@@ -373,11 +360,11 @@ void push_arraytemp(basicarray *descriptor, int32 type) {
 /*
 ** 'push_proc' pushes the return address and so forth for a procedure call
 */
-void push_proc(char *name, int32 count) {
+fnprocinfo *push_proc(char *name, int32 count) {
   basicvars.stacktop.bytesp-=ALIGNSIZE(stack_proc);
   if (basicvars.stacktop.bytesp<basicvars.stacklimit.bytesp) {
     error(ERR_STACKFULL);
-    return;
+    return(NULL);
   }
   basicvars.stacktop.procsp->itemtype = STACK_PROC;
   basicvars.stacktop.procsp->fnprocblock.lastcall = basicvars.procstack;
@@ -388,6 +375,7 @@ void push_proc(char *name, int32 count) {
 #ifdef DEBUG
   if (basicvars.debug_flags.stack) fprintf(stderr, "Saving PROC return block at %p\n", basicvars.stacktop.procsp);
 #endif
+  return(&basicvars.stacktop.procsp->fnprocblock);
 }
 
 /*
@@ -1442,12 +1430,17 @@ errorblock pop_error(void) {
 ** required sort. (This should be the most common case)
 */
 void empty_stack(stackitem required) {
-  while (GET_TOPITEM && GET_TOPITEM!=required)
+  while (GET_TOPITEM && (GET_TOPITEM!=required))
+    discard(GET_TOPITEM, 1);
+}
+
+void empty_stack_to_fn_or_proc() {
+  while (GET_TOPITEM && (GET_TOPITEM!=STACK_FN) && (GET_TOPITEM != STACK_PROC))
     discard(GET_TOPITEM, 1);
 }
 
 stackitem stack_unwindlocal() {
-  while (GET_TOPITEM && GET_TOPITEM!=STACK_ERROR && GET_TOPITEM!=STACK_PROC && GET_TOPITEM!=STACK_FN)
+  while (GET_TOPITEM && GET_TOPITEM==STACK_LOCAL)
     discard(GET_TOPITEM, 1);
   return GET_TOPITEM;
 }
